@@ -1,8 +1,10 @@
 import argparse
 from pathlib import Path
-from pyhabitat.environment import main
-from pyhabitat.utils import get_version
-import pyhabitat
+from .environment import main
+from .environment import * # to enable CLI --list
+from .utils import get_version
+#import __init__ as pyhabitat # works if everything is in root, v1.0.28
+import pyhabitat # refers to the folder
 
 def run_cli():
     """Parse CLI arguments and run the pyhabitat environment report."""
@@ -14,7 +16,7 @@ def run_cli():
     parser.add_argument(
         '-v', '--version', 
         action='version', 
-        version=f'%(prog)s {current_version}'
+        version=f'PyHabitat {current_version}'
     )
     # Add the path argument
     parser.add_argument(
@@ -34,6 +36,11 @@ def run_cli():
         action="store_true",
         help="List available callable functions in pyhabitat"
     )
+    #parser.add_argument(
+    #    "--verbose",
+    #    action="store_true",
+    #    help="List available callable functions in pyhabitat"
+    #)
                 
     parser.add_argument(
         "command",
@@ -45,11 +52,15 @@ def run_cli():
     args = parser.parse_args()
 
     if args.list:
-        for name in dir(pyhabitat):
-            if callable(getattr(pyhabitat, name)) and not name.startswith("_"):
+        for name in pyhabitat.__all__:
+            func = getattr(pyhabitat, name, None)
+            if callable(func):
                 print(name)
+                if args.debug:
+                    doc = func.__doc__ or "(no description)"
+                    print(f"{name}: {doc}")
         return
-
+                  
     if args.command:
         func = getattr(pyhabitat, args.command, None)
         if callable(func):
